@@ -181,7 +181,8 @@ NESTED_TAGS = (
         "outer_closing_tag": "</blockquote>",
         "inner_opening_tag": "<p>",
         "inner_closing_tag": "</p>",
-        "inner_ignore_tags": INDEPENDENT_TAGS
+        "inner_ignore_tags": INDEPENDENT_TAGS,
+        "minimum_level": 1
     },
     {
         "regex": REGEX_ORDERED_LIST,
@@ -189,7 +190,8 @@ NESTED_TAGS = (
         "outer_closing_tag": "</ol>",
         "inner_opening_tag": "<li>",
         "inner_closing_tag": "</li>",
-        "inner_ignore_tags": None
+        "inner_ignore_tags": None,
+        "minimum_level": 0
     },
     {
         "regex": REGEX_UNORDERED_LIST,
@@ -197,7 +199,8 @@ NESTED_TAGS = (
         "outer_closing_tag": "</ul>",
         "inner_opening_tag": "<li>",
         "inner_closing_tag": "</li>",
-        "inner_ignore_tags": None
+        "inner_ignore_tags": None,
+        "minimum_level": 0
     }
 )
 
@@ -337,10 +340,19 @@ def convert_nested_tag(line, cur_tag, open_tags):
     except IndexError:
         last_tag_level = 0
     try:
-        cur_tag_level = max(1, len(match[1]))
+        # 1 is added to ensure level is never less than 1. This prevents
+        # inconsistent behavior from arising due to lists minimum level being
+        # zero, and blockquotes minimum level being 1. This mainly addresses
+        # inconsistencies when tags are used separately.
+        cur_tag_level = len(match[1]) + 1
     except TypeError:
         cur_tag_level = 1
 
+    # Tag minimum level is removed from the current level due to the same
+    # reason as above. This mainly addresses inconsistencies when tags are
+    # mixed.
+    cur_tag_level -= cur_tag["minimum_level"]
+
     content = convert_inline(match[2])
 
     # If current level is greater than last level, open a new tag, then append
@@ -425,15 +437,22 @@ def convert(string):
     if string.strip() == "":
         return ""
 
+    open_tags = []
+    new_string = ""
+    add_line_break = False
+    open_paragraph = False
+
+    def convert_paragraph(line):
+        nonlocal open_paragraph
+        if not open_paragraph:
+            open_paragraph = True
+            return f"<p>{line.lstrip()}"
+        return line
+
     # Ensure string ends with a newline to prevents inconsistencies.
     while string.splitlines()[-1] != "":
         string += "\n"
 
-    open_tags = []
-    new_string = ""
-    open_paragraph = False
-    add_line_break = False
-
     for line in string.splitlines():
         new_line = ""
 
@@ -482,14 +501,14 @@ def convert(string):
             for tag in reversed(open_tags):
                 new_line += tag[0]["outer_closing_tag"]
                 open_tags.remove(tag)
+            if is_paragraph(line):
+                new_line += convert_paragraph(line)
+            else:
+                new_line += line
 
         # If not, check if line is a paragraph, if so, open a paragraph.
         elif is_paragraph(line):
-            if not open_paragraph:
-                open_paragraph = True
-                new_line = f"<p>{line.lstrip()}"
-            else:
-                new_line = line
+            new_line += convert_paragraph(line)
 
         # If not, just add the line as it is.
         else:
